OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Korak 1 nije uspio. Izuzetak: %s",
    "Step 2 failed. Exception: %s" : "Korak 2 nije uspio. Izuzetak: %s",
    "External storage" : "Vanjsko spremište za pohranu",
    "Personal" : "Osobno",
    "System" : "Sustav",
    "Grant access" : "Dodijeli pristup",
    "All users. Type to select user or group." : "Svi korisnici. Započnite unos za izbor korisnika ili grupe.",
    "(group)" : "(grupa)",
    "Saved" : "Spremljeno",
    "Username" : "Korisničko ime",
    "Password" : "Lozinka",
    "Save" : "Spremi",
    "App key" : "Ključ za aplikacije",
    "App secret" : "Tajna aplikacije",
    "Client ID" : "ID klijenta",
    "Client secret" : "Klijentski tajni ključ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Kantica",
    "Hostname" : "Naziv poslužitelja",
    "Port" : "Port",
    "Region" : "Regija",
    "Enable SSL" : "Omogućite SSL",
    "Enable Path Style" : "Omogućite Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Udaljena podmapa",
    "Secure https://" : "Siguran https://",
    "Local" : "Lokalno",
    "Location" : "Lokacija",
    "ownCloud" : "OwnCloud",
    "Host" : "Glavno računalo",
    "Root" : "Korijen",
    "Share" : "Dijeljenje zhajedničkih resursa",
    "SMB / CIFS using OC login" : "SMB / CIFS uz prijavu putem programa OC",
    "Username as share" : "Korisničko ime kao dijeljeni resurs",
    "OpenStack Object Storage" : "Prostor za pohranu.....",
    "<b>Note:</b> " : "<b>Bilješka:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> Podrška cURL u PHP nije omogućena ili nije instalirana. Postavljanje%s nije moguće. Molimo zamolite svog administratora sustava da je instalira.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Note:</b> \"%s\" nije instaliran. Postavljanje %s nije moguće. Molimo zamolitesvog administratora sustava da ga instalira.",
    "Name" : "Naziv",
    "Storage type" : "Vrsta spremišta",
    "Scope" : "Opseg",
    "External Storage" : "Vanjsko spremište",
    "Folder name" : "Naziv mape",
    "Configuration" : "Konfiguracija",
    "Available for" : "Dostupno za",
    "Add storage" : "Dodajte spremište",
    "Delete" : "Izbrišite",
    "Allow users to mount the following external storage" : "Dopustite korisnicima postavljanje sljedećeg vanjskog spremišta"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
